
## CATO-CLI - mutation.policy.appTenantRestriction.discardPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.appTenantRestriction.discardPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.appTenantRestriction.discardPolicyRevision:

```bash
catocli mutation policy appTenantRestriction discardPolicyRevision -h

catocli mutation policy appTenantRestriction discardPolicyRevision <json>

catocli mutation policy appTenantRestriction discardPolicyRevision --json-file mutation.policy.appTenantRestriction.discardPolicyRevision.json

catocli mutation policy appTenantRestriction discardPolicyRevision '{"appTenantRestrictionPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"policyDiscardRevisionInput":{"id":"id"}}'

catocli mutation policy appTenantRestriction discardPolicyRevision '{
    "appTenantRestrictionPolicyMutationInput": {
        "policyMutationRevisionInput": {
            "id": "id"
        }
    },
    "policyDiscardRevisionInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for mutation.policy.appTenantRestriction.discardPolicyRevision ####

`accountId` [ID] - (required) N/A    
`appTenantRestrictionPolicyMutationInput` [AppTenantRestrictionPolicyMutationInput] - (required) N/A    
`policyDiscardRevisionInput` [PolicyDiscardRevisionInput] - (required) N/A    
